]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Add SR_ERR_ARG #define.
[libsigrok.git] / sigrok.h
index 46a994586cef66706cb4bb8827e4290fa2ced76b..1ad12e96dea80b0f0896b557f16c7c93bf9085a8 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -25,7 +25,9 @@
 #include <stdint.h>
 #include <inttypes.h>
 #include <glib.h>
+#ifdef HAVE_LIBUSB_1_0
 #include <libusb.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -51,28 +53,21 @@ extern "C" {
 #define SR_OK                 0 /* No error */
 #define SR_ERR               -1 /* Generic/unspecified error */
 #define SR_ERR_MALLOC        -2 /* Malloc/calloc/realloc error */
-#define SR_ERR_SAMPLERATE    -3 /* Incorrect samplerate */
+#define SR_ERR_ARG           -3 /* Function argument error */
+#define SR_ERR_SAMPLERATE    -4 /* Incorrect samplerate */
 
-/* limited by uint64_t */
-#define MAX_NUM_PROBES 64
-#define MAX_PROBENAME_LEN 32
+#define SR_MAX_NUM_PROBES      64 /* Limited by uint64_t. */
+#define SR_MAX_PROBENAME_LEN   32
 
 /* Handy little macros */
-#define KHZ(n) ((n) * 1000)
-#define MHZ(n) ((n) * 1000000)
-#define GHZ(n) ((n) * 1000000000)
-
-#define HZ_TO_NS(n) (1000000000 / (n))
-
-#ifndef ARRAY_SIZE
-#define ARRAY_SIZE(a) (sizeof(a) / sizeof((a)[0]))
-#endif
+#define SR_HZ(n)  (n)
+#define SR_KHZ(n) ((n) * 1000)
+#define SR_MHZ(n) ((n) * 1000000)
+#define SR_GHZ(n) ((n) * 1000000000)
 
-#ifndef ARRAY_AND_SIZE
-#define ARRAY_AND_SIZE(a) (a), ARRAY_SIZE(a)
-#endif
+#define SR_HZ_TO_NS(n) (1000000000 / (n))
 
-typedef int (*receive_data_callback) (int fd, int revents, void *user_data);
+typedef int (*sr_receive_data_callback) (int fd, int revents, void *user_data);
 
 /* Data types used by hardware plugins for set_configuration() */
 enum {
@@ -85,12 +80,14 @@ enum {
        SR_PROTO_RAW,
 };
 
+#if 0
 /* (Unused) protocol decoder stack entry */
-struct protocol {
+struct sr_protocol {
        char *name;
        int id;
        int stackindex;
 };
+#endif
 
 /* sr_datafeed_packet.type values */
 enum {
@@ -118,16 +115,18 @@ struct sr_datafeed_header {
        int num_logic_probes;
 };
 
-struct analog_probe {
+#if 0
+struct sr_analog_probe {
        uint8_t att;
        uint8_t res;    /* Needs to be a power of 2, FIXME */
        uint16_t val;   /* Max hardware ADC width is 16bits */
 };
 
-struct analog_sample {
+struct sr_analog_sample {
        uint8_t num_probes; /* Max hardware probes is 256 */
-       struct analog_probe probes[];
+       struct sr_analog_probe probes[];
 };
+#endif
 
 struct sr_input {
        struct sr_input_format *format;
@@ -155,13 +154,14 @@ struct sr_output_format {
        char *description;
        int df_type;
        int (*init) (struct sr_output *o);
-       int (*data) (struct sr_output *o, char *data_in, uint64_t length_in,
-                    char **data_out, uint64_t *length_out);
+       int (*data) (struct sr_output *o, const char *data_in,
+                    uint64_t length_in, char **data_out, uint64_t *length_out);
        int (*event) (struct sr_output *o, int event_type, char **data_out,
                      uint64_t *length_out);
 };
 
-struct analyzer {
+#if 0
+struct sr_analyzer {
        char *name;
        char *filename;
        /*
@@ -169,11 +169,9 @@ struct analyzer {
         * TODO: Input and output format?
         */
 };
+#endif
 
-/* Size of a chunk in units */
-#define DATASTORE_CHUNKSIZE 512000
-
-struct datastore {
+struct sr_datastore {
        /* Size in bytes of the number of units stored in this datastore */
        int ds_unitsize;
        unsigned int num_units; /* TODO: uint64_t */
@@ -191,10 +189,10 @@ struct sr_device {
        struct sr_device_plugin *plugin;
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
/* List of struct probe* */
        GSList *probes;
        /* Data acquired by this device, if any */
-       struct datastore *datastore;
+       struct sr_datastore *datastore;
 };
 
 enum {
@@ -202,7 +200,7 @@ enum {
        SR_PROBE_TYPE_ANALOG,
 };
 
-struct probe {
+struct sr_probe {
        int index;
        int type;
        gboolean enabled;
@@ -210,6 +208,7 @@ struct probe {
        char *trigger;
 };
 
+/* TODO: Get rid of this global variable. */
 extern GSList *devices;
 
 /* Hardware plugin capabilities */
@@ -224,13 +223,18 @@ enum {
        SR_HWCAP_CAPTURE_RATIO,     /* Set pre/post-trigger capture ratio */
        SR_HWCAP_PATTERN_MODE,      /* Pattern generator mode */
 
+       /* special stuff */
+       SR_HWCAP_CAPTUREFILE,       /* capturefile to inject */
+       SR_HWCAP_CAPTURE_UNITSIZE,  /* unitsize of capturefile data */
+       SR_HWCAP_CAPTURE_NUM_PROBES,/* set number of probes */
+
        /* acquisition modes */
        SR_HWCAP_LIMIT_MSEC,        /* Set a time limit for sample acquisition */
        SR_HWCAP_LIMIT_SAMPLES,     /* Set a limit on number of samples */
        SR_HWCAP_CONTINUOUS,
 };
 
-struct hwcap_option {
+struct sr_hwcap_option {
        int capability;
        int type;
        char *description;
@@ -257,11 +261,13 @@ enum {
        SR_SERIAL_INSTANCE,
 };
 
+#ifdef HAVE_LIBUSB_1_0
 struct sr_usb_device_instance {
        uint8_t bus;
        uint8_t address;
        struct libusb_device_handle *devhdl;
 };
+#endif
 
 struct sr_serial_device_instance {
        char *port;
@@ -290,7 +296,7 @@ enum {
        SR_DI_INSTANCE,
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
/* Samplerates supported by this device, (struct samplerates) */
        SR_DI_SAMPLERATES,
        /* Types of trigger supported, out of "01crf" (char *) */
        SR_DI_TRIGGER_TYPES,
@@ -305,7 +311,7 @@ enum {
  * granularity, or is limited to a set of defined samplerates. Use either
  * step or list, but not both.
  */
-struct samplerates {
+struct sr_samplerates {
        uint64_t low;
        uint64_t high;
        uint64_t step;
@@ -317,7 +323,7 @@ struct sr_device_plugin {
        char *name;
        char *longname;
        int api_version;
-       int (*init) (char *deviceinfo);
+       int (*init) (const char *deviceinfo);
        void (*cleanup) (void);
 
        /* Device-specific */
@@ -331,12 +337,12 @@ struct sr_device_plugin {
        void (*stop_acquisition) (int device_index, gpointer session_device_id);
 };
 
-struct session {
+struct sr_session {
        /* List of struct sr_device* */
        GSList *devices;
        /* List of struct analyzer* */
        GSList *analyzers;
-       /* list of receive_data_callback */
+       /* list of sr_receive_data_callback */
        GSList *datafeed_callbacks;
        GTimeVal starttime;
        gboolean running;
@@ -191,10 +189,10 @@ struct sr_device {
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
-       /* List of struct probe* */
+       /* List of struct sr_probe* */
        GSList *probes;
        /* Data acquired by this device, if any */
@@ -290,7 +296,7 @@ enum {
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
-       /* Samplerates supported by this device, (struct samplerates) */
+       /* Samplerates supported by this device, (struct sr_samplerates) */
        SR_DI_SAMPLERATES,
        /* Types of trigger supported, out of "01crf" (char *) */